@@ -1,11 +1,14 @@
 import copy
 
 from django.contrib import admin
+from django.contrib.postgres.fields import DateRangeField
 from django_object_actions import DjangoObjectActions
 
 from .actions import form_processing_action, object_action, queryset_action
 from .decorators import options
+from .logging import log_action, log_addition, log_change, log_deletion
 from .widgets import (
+    AdminDateRangeWidget,
     admin_detail_link,
     boolean_icon_with_text,
     formatted_json,
@@ -14,21 +17,25 @@ from .widgets import (
 )
 
 
-__version__ = "0.0.11"
+__version__ = "0.0.12"
 __url__ = "https://github.com/GaretJax/django-adminutils"
 __author__ = "Jonathan Stoppani"
 __email__ = "jonathan@stoppani.name"
 __license__ = "MIT"
 __all__ = [
+    "boolean_icon_with_text",
+    "formatted_json",
+    "form_processing_action",
+    "html_list",
+    "log_action",
+    "log_addition",
+    "log_change",
+    "log_deletion",
+    "ModelAdmin",
+    "object_action",
     "options",
     "queryset_action",
     "simple_code_block",
-    "object_action",
-    "ModelAdmin",
-    "boolean_icon_with_text",
-    "form_processing_action",
-    "formatted_json",
-    "html_list",
 ]
 
 
@@ -108,6 +115,10 @@ class EditOnlyInlineMixin:
 
 
 class ModelAdmin(DjangoObjectActions, admin.ModelAdmin):
+    formfield_overrides = {
+        DateRangeField: {"widget": AdminDateRangeWidget},
+    }
+
     class Media:
         css = {
             "all": ("admin/css/overrides.css",),
